﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using DotNetLibs.Security;

namespace DotNetLibs.Samples
{
	class Program
	{
		static void Main(string[] args)
		{
			// set the trial license key
			DotNetLibs.Licensing.Key = DotNetLibs.Examples.TrialKey.Key;

		    Arguments arguments;
			try
			{
			    // parse arguments
			    arguments = new Arguments(args);
			}
			catch (Exception e)
			{
				// display an error reported by arguments parser class
				ShowHelp();
				Console.WriteLine();
				Console.WriteLine("Error: {0}", e.Message);
			    return;
			}

            try
            {
                // initialize FileEncryption object
				FileEncryption cryption = new FileEncryption();
				cryption.SetPassword(arguments.Password);
				cryption.OverwriteExistingFile = arguments.Overwrite;

				// perform specified operation
				if (arguments.Operation == Operation.Encrypt)
				{
					cryption.Encrypt(arguments.SourceFile, arguments.DestinationFile);
					Console.WriteLine("File successfully encrypted.");
				}
				else
				{
					cryption.Decrypt(arguments.SourceFile, arguments.DestinationFile);
					Console.WriteLine("File successfully decrypted.");
				}
			}
			catch (IOException ex)
			{
				// display IO error
				Console.WriteLine(ex.Message);
			}
			catch (InvalidOperationException ex)
			{
				// display invalid operation error
				Console.WriteLine(ex.Message);
			}
			catch (Exception ex)
			{
				// display all other errors
				Console.WriteLine("Error: {0}", ex);
			}
		}

		static void ShowHelp()
		{
			string encrypt = Operation.Encrypt.ToString().ToLower();
			string decrypt = Operation.Decrypt.ToString().ToLower();
			string applicationName = AppDomain.CurrentDomain.FriendlyName;

			Console.WriteLine("=====================================================================");
			Console.WriteLine(" DotNetLibs {0} - Encrypts or decrypts files", applicationName);
			Console.WriteLine("=====================================================================");
			Console.WriteLine();
			Console.WriteLine("The program is a sample for DotNetLibs Security for .NET component.");
            Console.WriteLine("For more info, see http://www.dotnetlibs.com/encryption.php/");
			Console.WriteLine();
			Console.WriteLine(@"Syntax: {0} {1}|{2} <source file> <destination file> password [overwrite]", applicationName, encrypt, decrypt);
			Console.WriteLine(@"Example: {0} {1} C:\file.txt C:\file.enc secret-password overwrite", applicationName, encrypt);
			Console.WriteLine(@"Example: {0} {1} C:\file.enc C:\file.txt secret-password", applicationName, decrypt);
		}
	}
}